/**
* Copyright (C) 2004-2005 Pantelis Frangoudis, Elias Efstathiou
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

package P2PWNC;

/**
 * Abstract class that includes the P2PWNC protocol constants, such as message types.
 * All other classes the P2PWNC client software is comprised of extend this class.
 *
 * @author Pantelis Frangoudis
 * @author Elias Efstathiou
 * @version 0.0.1
 */
abstract class P2PWNCProto {
  /**
   * The standard port a service provider listens for client messages, as specified by the P2PWNC protocol).
   */
  public final static int P2PWNC_SERVER_PORT = 9999;

  /**
   * RSA cryptosystem identifier.
   */
  public final static int P2PWNC_ALGO_RSA = 10;

  /**
   * Elliptic Curve cryptosystem identifier.
   */
  public final static int P2PWNC_ALGO_ECC = 20;

  /**
   * This message type corresponds to a P2PWNC "receipt" message (RCPT).
   */
  public final static int P2PWNC_MSG_RCPT = 10;

  /**
   * This message type corresponds to a P2PWNC "connect" message (CONN).
   */
  public final static int P2PWNC_MSG_CONN = 20;

  /**
   * This message type corresponds to a P2PWNC "receipt request" message (RREQ).
   */
  public final static int P2PWNC_MSG_RREQ = 30;

  /**
   * This message type corresponds to a P2PWNC "connection acknowledgement" message (CACK).
   */
  public final static int P2PWNC_MSG_CACK = 40;

  /**
   * This message type corresponds to a P2PWNC "tear connection" message (TEAR).
   */
  public final static int P2PWNC_MSG_TEAR = 80;
}
