/**
* Copyright (C) 2004-2005 Pantelis Frangoudis, Elias Efstathiou
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

package P2PWNC;

/**
 * This class represents a P2PWNC RREQ protocol message.
 * It includes the service provider's public key and the (next) receipt weight.
 *
 * @author Pantelis Frangoudis
 * @author Elias Efstathiou
 * @version 0.0.1
 */
class P2PWNCRREQMsgInfo {


    /**
     * Service provider's public key.
     */
    protected P2PWNCKey providerKey;

    /**
     * Weight of the next receipt. Namely, this is the value of the "weight" field of an
     * RREQ message. Its meaning is that the provider wishes that the consumer will acknowledge that
     * she has consumed service of "weight" bytes during a session.
     */
    protected int weight;

    /**
     * Constructs a P2PWNCRREQMsgInfo object with the specified provider key and weight field values.
     * @param key P2PWNCKey
     * The public key of the service provider.
     * @param weight int
     * The receipt weight.
     */
    P2PWNCRREQMsgInfo(P2PWNCKey key, int weight) {
        this.providerKey = key;
        this.weight = weight;
    }

    /**
     * Returns the public key of the service provider of a P2PWNCRREQMsgInfo object.
     * @return P2PWNCKey
     */
    public P2PWNCKey getProviderKey() {
        return this.providerKey;
    }

    /**
     * Returns the value of the weight field of a P2PWNCRREQMsgInfo object.
     * @return int
     */
    public int getWeight() {
        return weight;
    }
}

