/**
* Copyright (C) 2004-2005 Pantelis Frangoudis, Elias Efstathiou
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

package P2PWNC;

/**
 * This class represents a P2PWNC protocol receipt. A receipt is composed of the consumer's certificate,
 * provider public key, session timestamp and receipt weight. All the above (in that order), are serialized
 * and signed using the consumer's private key. The receipt signature (instance of the P2PWNCSignature class) is
 * added to the P2PWNCReceipt object (receiptSignature field).
 *
 * @author Pantelis Frangoudis
 * @author Elias Efstathiou
 * @version 0.0.1
 */
class P2PWNCReceipt extends P2PWNCProto {
        protected P2PWNCCert consumerCert;
        protected P2PWNCKey providerPublicKey;
        protected int timestamp;
        protected int weight;
        protected P2PWNCSignature receiptSignature;

        P2PWNCReceipt() {
                this.consumerCert = null;
                this.providerPublicKey = null;
                this.timestamp = 0;
                this.weight = 0;
                this.receiptSignature = null;
        }


        P2PWNCReceipt(P2PWNCCert consumerCert, P2PWNCKey providerPublicKey, int timestamp, int weight, P2PWNCSignature receiptSignature) {
                this.consumerCert = consumerCert;
                this.providerPublicKey = providerPublicKey;
                this.timestamp = timestamp;
                this.weight = weight;
                this.receiptSignature = receiptSignature;
        }

        public P2PWNCCert getConsumerCert() {
                return this.consumerCert;
        }

        public P2PWNCKey getProviderPublicKey() {
                return this.providerPublicKey;
        }

        public int getTimestamp() {
                return this.timestamp;
        }

        public int getWeight() {
                return this.weight;
        }

        public P2PWNCSignature getReceiptSignature() {
                return this.receiptSignature;
        }

        public void setConsumerCert(P2PWNCCert consumerCert) {
                this.consumerCert = consumerCert;
        }

        public void setProviderPublicKey(P2PWNCKey providerPublicKey) {
                this.providerPublicKey = providerPublicKey;
        }

        public void setTimestamp(int timestamp) {
                this.timestamp = timestamp;
        }

        public void setWeight(int weight) {
                this.weight = weight;
        }

        public void setReceiptSignature(P2PWNCSignature receiptSignature) {
                this.receiptSignature = receiptSignature;
        }
}
